@@ -1,5 +1,20 @@
 #!/usr/bin/perl
 
+# Copyright (C) 2008-2010 eBox Technologies S.L.
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License, version 2, as
+# published by the Free Software Foundation.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+
 #
 #   gconf changes: filterSettigns data moved to default profile data
 #   depending in pid files
@@ -63,10 +78,9 @@ sub _moveGConfDir
         my $oldEntry = $modDir . '/' . $oldDir . '/' . $entry;
         my $newEntry = $modDir . '/' . $newDir . '/' . $entry;
 
-        my $gclient = Gnome2::GConf::Client->get_default;
-        my $value = $gclient->get($oldEntry);
-        $gclient->set($newEntry, $value);
-        $gclient->unset($oldEntry);
+        my $value = $mod->get($oldEntry);
+        $mod->set($newEntry, $value);
+        $mod->unset($oldEntry);
     }
 }
 
