@@ -1,4 +1,4 @@
-# Copyright (C) 2005 Warp Networks S.L., DBS Servicios Informaticos S.L.
+# Copyright (C) 2008-2010 eBox Technologies S.L.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License, version 2, as
@@ -25,7 +25,7 @@ use EBox::Gettext;
 use constant  SQUIDLOGFILE => '/var/log/squid/access.log';
 use constant  DANSGUARDIANLOGFILE => '/var/log/dansguardian/access.log';
 
-sub new 
+sub new
 {
         my $class = shift;
         my $self = {};
@@ -33,12 +33,12 @@ sub new
         return $self;
 }
 
-sub domain { 
+sub domain {
         return 'ebox-squid';
 }
 
 
-# Method: logFiles 
+# Method: logFiles
 #
 #	This function must return the file or files to be read from.
 #
@@ -57,24 +57,23 @@ sub logFiles
 #	the associated file. You must parse the line, and generate
 #	the messages which will be logged to ebox through an object
 #	implementing EBox::AbstractLogger interface.
-#
 # Parameters:
 #
 #	file - file name
 # 	line - string containing the log line
 #	dbengine- An instance of class implemeting AbstractDBEngineinterface
 #
-sub processLine # (file, line, logger) 
+sub processLine # (file, line, logger)
 {
 	my ($self, $file, $line, $dbengine) = @_;
         chomp $line;
-		
+
 	my @fields = split (/\s+/, $line);
-	
+
 	if ($fields[2] eq '127.0.0.1') {
 		return;
 	}
-	
+
 	my $event;
 	if (($fields[3] eq 'TCP_DENIED/403') and ($file eq  DANSGUARDIANLOGFILE)) {
 		$event = 'filtered';
@@ -82,25 +81,26 @@ sub processLine # (file, line, logger)
 		$event = 'denied';
 	} else {
 		$event = 'accepted';
-	}	
-	
+	}
+
 
         my $time = localtime $fields[0];
-        my $data = { 
-            'timestamp' => $time, 
-            'elapsed' => $fields[1], 
-            'remotehost' => $fields[2], 
+        my $data = {
+            'timestamp' => $time,
+            'elapsed' => $fields[1],
+            'remotehost' => $fields[2],
             'code' => $fields[3],
-            'bytes' => $fields[4], 
+            'bytes' => $fields[4],
             'method' => $fields[5],
-            'url' => $fields[6], 
+             # Trim URL string as DB stores it as a varchar(1024)
+            'url' => substr($fields[6], 0, 1023),
             'rfc931' => $fields[7],
-            'peer' => $fields[8], 
+            'peer' => $fields[8],
             'mimetype' => $fields[9],
             'event' => $event
            };
-	
-        
+
+
 	$dbengine->insert('squid_access', $data);
 }
 
