@@ -1,4 +1,4 @@
-# Copyright (C) 2009 Warp Networks S.L.
+# Copyright (C) 2009-2010 eBox Technologies S.L.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License, version 2, as
@@ -19,7 +19,6 @@ use base 'EBox::Model::DataTable';
 use strict;
 use warnings;
 
-# eBox uses
 use EBox;
 
 use EBox::Exceptions::Internal;
@@ -73,7 +72,9 @@ sub _validateUrl
     my ($domain, $dir) = split '/', $url, 2;
     $dir = '/' . $dir;
 
-    EBox::Validate::checkDomainName($domain, __('Domain or IP address'));
+    EBox::Validate::checkDomainName($domain, 
+                                    __('Domain or IP address part of URL')
+                                   );
 }
 
 sub _validateDomain
