@@ -1,4 +1,4 @@
-# Copyright (C) 2007 Warp Networks S.L.
+# Copyright (C) 2008-2010 eBox Technologies S.L.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License, version 2, as
@@ -79,24 +79,22 @@ sub _table
   }
 
 
-# # # XXX ad-hack reimplementation until the bug in coposite's parent would be
+# # # XXX ad-hack reimplementation until the bug in composite's parent would be
 # # # solved
-# # use EBox::Global;
-# sub parent
-# {
-#     my ($self) = @_;
+use EBox::Global;
+sub parent
+{
+    my ($self) = @_;
 
-#     my $squid     = EBox::Global->modInstance('squid');
+    my $squid     = EBox::Global->modInstance('squid');
 
 
-#     my $defaultFilterGroup = $squid->composite('FilterSettings');
+    my $defaultFilterGroup = $squid->composite('FilterSettings');
 
-#     my $parent =  $defaultFilterGroup->componentByName('DomainFilterFiles', 1);
+    my $parent =  $defaultFilterGroup->componentByName('DomainFilterFiles', 1);
 
-#     EBox::debug("PPARENT $parent");
-
-#     return $parent;
-# }
+    return $parent;
+}
 
 # Method: viewCustomizer
 #
