@@ -1,4 +1,4 @@
-# Copyright (C) 2007 Warp Networks S.L.
+# Copyright (C) 2008-2010 eBox Technologies S.L.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License, version 2, as
@@ -25,7 +25,6 @@ use base 'EBox::Model::DataTable';
 #   It subclasses <EBox::Model::DataTable>
 #
 
-# eBox uses
 use EBox;
 
 use EBox::Exceptions::Internal;
@@ -33,7 +32,7 @@ use EBox::Gettext;
 use EBox::Types::Text;
 use EBox::Squid::Types::Policy;
 use EBox::Squid::Types::TimePeriod;
-
+use EBox::NetWrappers;
 
 # Group: Public methods
 
@@ -91,8 +90,7 @@ sub _table
                            editable => 1,
                           ),
 
-     new EBox::Types::HasMany
-     (
+     new EBox::Types::HasMany (
       'fieldName' => 'groupPolicy',
       'printableName' => __('Group policy'),
       'foreignModel' => 'ObjectGroupPolicy',
@@ -100,7 +98,16 @@ sub _table
       'backView' => '/ebox/Squid/View/ObjectGroupPolicy',
       'size' => '1',
      ),
+     new EBox::Types::Select(
+                             fieldName => 'filterGroup',
+                             printableName => __('Filter profile'),
 
+                             foreignModel  => \&filterGroupModel,
+                             foreignField  => 'name',
+                             
+                             defaultValue  => 'default',
+                             editable      => 1,
+                            ),
     );
 
   my $dataTable =
@@ -139,6 +146,13 @@ sub objectModel
     return $objects->{'objectModel'};
 }
 
+sub filterGroupModel
+{
+    my ($self) = @_;
+    my $sq = EBox::Global->modInstance('squid');
+    return $sq->model('FilterGroup');
+}
+
 
 sub name
 {
@@ -151,6 +165,7 @@ sub validateTypedRow
   $self->_checkPolicyWithTransProxy($params_r, $actual_r);
   $self->_checkPolicyWithTimePeriod($params_r, $actual_r);
   $self->_checkPolicyWithGroupsPolicy($params_r, $actual_r);
+  $self->_checkFilterProfile($params_r, $actual_r);
 }
 
 
@@ -225,6 +240,33 @@ sub _checkPolicyWithGroupsPolicy
 
 }
 
+
+sub _checkFilterProfile
+{
+  my ($self, $params_r, $actual_r) = @_;
+
+  my $filterGroup = exists $params_r->{filterGroup} ?
+                     $params_r->{filterGroup} :
+                     $actual_r->{filterGroup} ;
+  if ($filterGroup->value() eq 'default') {
+      # default group is ocmpatible with all policies
+      return;
+  }
+  
+  my $policyElement = exists $params_r->{policy} ?
+                     $params_r->{policy} :
+                     $actual_r->{policy} ;
+
+  my $policy = $policyElement->value();
+  if ($policy ne 'filter') {
+      throw EBox::Exceptions::External(
+   __(q{You can only use a custom profile with the 'Filter' policy})
+                                      );
+  }
+
+}
+
+
 sub objectsPolicies
 {
   my ($self) = @_;
@@ -278,6 +320,49 @@ sub objectsPolicies
   return \@obsPol;
 }
 
+
+
+
+sub objectsFilterGroups
+{
+    my ($self) = @_;
+
+  my %filterGroupIdByRowId = %{ $self->filterGroupModel->idByRowId() };
+
+    my $objectMod = EBox::Global->modInstance('objects');
+
+    my @filterGroups;
+    # object polices have priority by position in table
+    foreach my $id (@{ $self->ids()  }) {
+        my $row = $self->row($id);
+        my $filterGroup = $row->valueByName('filterGroup');
+        if ($filterGroup eq 'default') {
+            next;
+        }
+        if ($row->valueByName('policy') ne 'filter') {
+            EBox::debug(
+"Object row with id $id has a custom filter group and a policy that is not 'filter'"
+                       );
+            next;
+        }
+
+        my $obj           = $row->valueByName('object');
+        my @addresses = @{ $objectMod->objectAddresses($obj)  };
+        foreach my $cidrAddress (@addresses) {
+            my ($addr, $netmask) = 
+                EBox::NetWrappers::to_network_without_mask($cidrAddress);
+            my $address = $addr . '/' . $netmask;;
+            push @filterGroups, { 
+                                 address=> $address, 
+                                 group  => $filterGroupIdByRowId{$filterGroup}  
+                                };
+        }
+    }
+
+    return \@filterGroups;
+}
+
+
 sub existsAuthObjects
 {
   my ($self) = @_;
