@@ -1,4 +1,4 @@
-# Copyright (C) 2005 Warp Networks S.L., DBS Servicios Informaticos S.L.
+# Copyright (C) 2008-2010 eBox Technologies S.L.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License, version 2, as
@@ -45,12 +45,16 @@ sub _trans_prerouting
     my @ifaces = @{$net->InternalIfaces()};
     my $pol = $sq->globalPolicy();
     foreach my $ifc (@ifaces) {
-        my $addr = $net->ifaceAddress($ifc);
-        (defined($addr) && $addr ne "") or next;
+        my $addrs = $net->ifaceAddresses($ifc);
+        my $input = $self->_inputIface($ifc);
 
-        my $r = "-i $ifc -d ! $addr -p tcp " .
-            "--dport 80 -j REDIRECT --to-ports $sqport";
-        push(@rules, $r);
+        foreach my $addr (map { $_->{address} } @{$addrs}) {
+            (defined($addr) && $addr ne "") or next;
+
+            my $r = "$input -d ! $addr -p tcp " .
+              "--dport 80 -j REDIRECT --to-ports $sqport";
+            push(@rules, $r);
+        }
     }
 
     return \@rules;
@@ -78,7 +82,8 @@ sub input
     my @ifaces = @{$net->InternalIfaces()};
     my $pol = $sq->globalPolicy();
     foreach my $ifc (@ifaces) {
-        my $r = "-m state --state NEW -i $ifc -p tcp --dport $sqport ".
+        my $input = $self->_inputIface($ifc);
+        my $r = "-m state --state NEW $input -p tcp --dport $sqport ".
             "-j ACCEPT";
         push(@rules, $r);
     }
@@ -88,7 +93,6 @@ sub input
 sub output
 {
     my ($self) = @_;
-    my $sq = EBox::Global->modInstance('squid');
     my @rules = ();
     push(@rules, "-m state --state NEW -p tcp --dport 80 -j ACCEPT");
     push(@rules, "-m state --state NEW -p tcp --dport 443 -j ACCEPT");
